==> otb_6.4.0+dfsg.orig.tar.xz: OTB-release-6.4/Modules/IO/IOBSQ/include/otbBSQImageIOFactory.h <==
/*
 * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
 *
 * This file is part of Orfeo Toolbox
 *
 *     https://www.orfeo-toolbox.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef otbBSQImageIOFactory_h
#define otbBSQImageIOFactory_h

#include "itkObjectFactoryBase.h"

namespace otb
{
/** \class BSQImageIOFactory
 * \brief Creation d'un instance d'un objet BSQImageIO utilisant les object factory.
 *
 * \ingroup OTBIOBSQ
 */
class ITK_EXPORT BSQImageIOFactory : public itk::ObjectFactoryBase
{
public:
  /** Standard class typedefs. */
  typedef BSQImageIOFactory             Self;
  typedef itk::ObjectFactoryBase        Superclass;
  typedef itk::SmartPointer<Self>       Pointer;
  typedef itk::SmartPointer<const Self> ConstPointer;

  /** Class methods used to interface with the registered factories. */
  const char* GetITKSourceVersion(void) const ITK_OVERRIDE;
  const char* GetDescription(void) const ITK_OVERRIDE;

  /** Method for class instantiation. */
  itkFactorylessNewMacro(Self);
  static BSQImageIOFactory * FactoryNew() { return new BSQImageIOFactory; }

  /** Run-time type information (and related methods). */
  itkTypeMacro(BSQImageIOFactory, itk::ObjectFactoryBase);

  /** Register one factory of this type  */
  static void RegisterOneFactory(void)
  {
    BSQImageIOFactory::Pointer BSQFactory = BSQImageIOFactory::New();
    itk::ObjectFactoryBase::RegisterFactoryInternal(BSQFactory);
  }

protected:
  BSQImageIOFactory();
  ~BSQImageIOFactory() ITK_OVERRIDE;

private:
  BSQImageIOFactory(const Self &); //purposely not implemented
  void operator =(const Self&); //purposely not implemented

};

} // end namespace otb

#endif

==> otb_6.6.1+dfsg.orig.tar.xz: OTB-release-6.6/Modules/IO/IOBSQ/include/otbBSQImageIOFactory.h <==
/*
 * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
 *
 * This file is part of Orfeo Toolbox
 *
 *     https://www.orfeo-toolbox.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef otbBSQImageIOFactory_h
#define otbBSQImageIOFactory_h

#include "itkObjectFactoryBase.h"

namespace otb
{
/** \class BSQImageIOFactory
 * \brief Creation d'un instance d'un objet BSQImageIO utilisant les object factory.
 *
 * \ingroup OTBIOBSQ
 */
class ITK_EXPORT BSQImageIOFactory : public itk::ObjectFactoryBase
{
public:
  /** Standard class typedefs. */
  typedef BSQImageIOFactory             Self;
  typedef itk::ObjectFactoryBase        Superclass;
  typedef itk::SmartPointer<Self>       Pointer;
  typedef itk::SmartPointer<const Self> ConstPointer;

  /** Class methods used to interface with the registered factories. */
  const char* GetITKSourceVersion(void) const override;
  const char* GetDescription(void) const override;

  /** Method for class instantiation. */
  itkFactorylessNewMacro(Self);
  static BSQImageIOFactory * FactoryNew() { return new BSQImageIOFactory; }

  /** Run-time type information (and related methods). */
  itkTypeMacro(BSQImageIOFactory, itk::ObjectFactoryBase);

  /** Register one factory of this type  */
  static void RegisterOneFactory(void)
  {
    BSQImageIOFactory::Pointer BSQFactory = BSQImageIOFactory::New();
    itk::ObjectFactoryBase::RegisterFactoryInternal(BSQFactory);
  }

protected:
  BSQImageIOFactory();
  ~BSQImageIOFactory() override;

private:
  BSQImageIOFactory(const Self &); //purposely not implemented
  void operator =(const Self&); //purposely not implemented

};

} // end namespace otb

#endif
